/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.dataone.tidy.concurrent;

import org.dataone.service.types.v1.Identifier;
import org.dataone.tidy.dao.ChangeRecordRepository;
import org.dataone.tidy.dao.MergeResultRepository;
import org.dataone.tidy.dao.SystemMetadataTidyDao;
import org.dataone.tidy.merge.MNSystemMetadataDelegate;

/**
 * Covers default implementation for TidyJob interface
 * All TidyJob instances must define their own call methods
 * 
 * All jobs in used in CompletionService should be able to be cast to AbstractTidyJobs
 * or, at least implement Comparable interface + equals and hashCode
 * @author waltz
 */
public abstract class AbstractTidyJob implements TidyJob, Comparable {

    protected ChangeRecordRepository changesRepo;
    protected MergeResultRepository resultsRepo;
    protected SystemMetadataTidyDao sysmetaRepo;
    protected MNSystemMetadataDelegate mnReadClient;

    protected Identifier pid = null;
    protected Exception failure = null;

    public AbstractTidyJob() {
    }

    @Override
    public Identifier getPid() {
        return pid;
    }

    @Override
    public void setPid(Identifier pid) {
        this.pid = pid;
    }

    @Override
    public Exception getFailure() {
        return failure;
    }

    @Override
    public void setFailure(Exception failure) {
        this.failure = failure;
    }

    @Override
    public abstract Object call() throws Exception;

    public MNSystemMetadataDelegate getMnReadClient() {
        return mnReadClient;
    }

    public void setMnReadClient(MNSystemMetadataDelegate mnReadClient) {
        this.mnReadClient = mnReadClient;
    }

    public void setMergeResultRepository(MergeResultRepository mergeResultRepository) {
        this.resultsRepo = mergeResultRepository;
    }

    public void setChangeRecordRepository(ChangeRecordRepository changeRecordRepository) {
        this.changesRepo = changeRecordRepository;
    }

    public void setSystemMetadataTidyDao(SystemMetadataTidyDao systemMetadataTidyDao) {
        this.sysmetaRepo = systemMetadataTidyDao;
    }
    
    /* 
     * a tidy Job is unique depending upon its pid and its failure
     * 
    */
   /** 
     * 1 value 2 Value 3 String 4 (java.lang.String) 5 Identifier  value is a string, override equals of Identifier.
     * @param other
     * @return boolean
     */
    @Override
    public boolean equals(Object other) {

        if (other == null || other.getClass() != this.getClass())
            return false;
        AbstractTidyJob otherTidyJob = (AbstractTidyJob) other;
        if (pid.equals(otherTidyJob.getPid()) && failure.equals(otherTidyJob.getFailure())) {
            return true;
        } else {
            return false;
        }
    }

    /** 
     * return the hashcode based on some bitwise math of the pid and failure hashCodes
     * 
     * derived from answers to 
     * http://stackoverflow.com/questions/2730865/how-do-i-calculate-a-good-hash-code-for-a-list-of-strings
     * 
     * @return int
     */
    @Override
    public int hashCode() {
     int shift = 0;
     int firstResult = (pid.hashCode() << shift) | (pid.hashCode() >> (32-shift)) & (1 << shift - 1);
     shift = 1;
     int secondResult = (failure.hashCode() << shift) | (failure.hashCode() >> (32-shift)) & (1 << shift - 1);
     return firstResult ^ secondResult;
    }

    /** 
     * Order based on the pid.
     * 
     * @param other
     * @return int
     * @throws ClassCastException 
     */
    @Override
    public int compareTo(Object other) throws ClassCastException {
        AbstractTidyJob otherIdentifier = (AbstractTidyJob) other;
        
        return pid.compareTo(otherIdentifier.getPid());
    } 
}
