SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: merged_identifier; Type: TABLE; Schema: public; Owner: metacat; Tablespace: 
--

DROP TABLE IF EXISTS merged_identifier; CREATE TABLE merged_identifier (
    guid text NOT NULL,
    docid character varying(250),
    rev bigint
);


ALTER TABLE public.merged_identifier OWNER TO metacat;

--
-- Name: merged_smreplicationpolicy; Type: TABLE; Schema: public; Owner: metacat; Tablespace: 
--

DROP TABLE IF EXISTS merged_smreplicationpolicy; CREATE TABLE merged_smreplicationpolicy (
    guid text,
    member_node character varying(250),
    policy text
);


ALTER TABLE public.merged_smreplicationpolicy OWNER TO metacat;

--
-- Name: merged_smreplicationstatus; Type: TABLE; Schema: public; Owner: metacat; Tablespace: 
--

DROP TABLE IF EXISTS merged_smreplicationstatus; CREATE TABLE merged_smreplicationstatus (
    guid text,
    member_node character varying(250),
    status character varying(250),
    date_verified timestamp without time zone
);


ALTER TABLE public.merged_smreplicationstatus OWNER TO metacat;

--
-- Name: merged_systemmetadata; Type: TABLE; Schema: public; Owner: metacat; Tablespace: 
--

DROP TABLE IF EXISTS merged_systemmetadata; CREATE TABLE merged_systemmetadata (
    guid text NOT NULL,
    serial_version character varying(256),
    date_uploaded timestamp without time zone,
    rights_holder character varying(250),
    checksum character varying(512),
    checksum_algorithm character varying(250),
    origin_member_node character varying(250),
    authoritive_member_node character varying(250),
    date_modified timestamp without time zone,
    submitter character varying(256),
    object_format character varying(256),
    size character varying(256),
    archived boolean,
    replication_allowed boolean,
    number_replicas bigint,
    obsoletes text,
    obsoleted_by text
);


ALTER TABLE public.merged_systemmetadata OWNER TO metacat;

--
-- Name: merged_xml_access; Type: TABLE; Schema: public; Owner: metacat; Tablespace: 
--

DROP TABLE IF EXISTS merged_xml; CREATE TABLE merged_xml_access (
    guid text,
    accessfileid text,
    principal_name character varying(100),
    permission bigint,
    perm_type character varying(32),
    perm_order character varying(32),
    begin_time date,
    end_time date,
    ticket_count bigint,
    subtreeid character varying(32),
    startnodeid bigint,
    endnodeid bigint,
    CONSTRAINT xml_access_ck CHECK ((begin_time < end_time))
);


ALTER TABLE public.merged_xml_access OWNER TO metacat;


--
-- Name: merged_identifier_pk; Type: CONSTRAINT; Schema: public; Owner: metacat; Tablespace: 
--

ALTER TABLE ONLY merged_identifier
    ADD CONSTRAINT merged_identifier_pk PRIMARY KEY (guid);


--
-- Name: merged_systemmetadata_pk; Type: CONSTRAINT; Schema: public; Owner: metacat; Tablespace: 
--

ALTER TABLE ONLY merged_systemmetadata
    ADD CONSTRAINT merged_systemmetadata_pk PRIMARY KEY (guid);


--
-- Name: merged_identifier_docid; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_identifier_docid ON merged_identifier USING btree (docid);


--
-- Name: merged_identifier_docid_rev; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_identifier_docid_rev ON merged_identifier USING btree (docid, rev);


--
-- Name: merged_identifier_docid_rev_log; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_identifier_docid_rev_log ON merged_identifier USING btree (((((docid)::text || '.'::text) || rev)));


--
-- Name: merged_identifier_guid; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_identifier_guid ON merged_identifier USING btree (guid);


--
-- Name: merged_identifier_rev; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_identifier_rev ON merged_identifier USING btree (rev);


--
-- Name: merged_xml_access_idx1; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_xml_access_idx1 ON merged_xml_access USING btree (lower((principal_name)::text));


--
-- Name: merged_xml_access_idx2; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_xml_access_idx2 ON merged_xml_access USING btree (permission);


--
-- Name: merged_xml_access_idx3; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_xml_access_idx3 ON merged_xml_access USING btree (perm_type);


--
-- Name: merged_xml_access_idx4; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_xml_access_idx4 ON merged_xml_access USING btree (perm_order);


--
-- Name: merged_xml_access_idx5; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_xml_access_idx5 ON merged_xml_access USING btree (subtreeid);


--
-- Name: merged_xml_access_idx6; Type: INDEX; Schema: public; Owner: metacat; Tablespace: 
--

CREATE INDEX merged_xml_access_idx6 ON merged_xml_access USING btree (guid);


--
-- Name: merged_systemmetadatareplicationpolicy_fk; Type: FK CONSTRAINT; Schema: public; Owner: metacat
--

ALTER TABLE ONLY merged_smreplicationpolicy
    ADD CONSTRAINT merged_systemmetadatareplicationpolicy_fk FOREIGN KEY (guid) REFERENCES merged_systemmetadata(guid) DEFERRABLE;


--
-- Name: merged_systemmetadatareplicationstatus_fk; Type: FK CONSTRAINT; Schema: public; Owner: metacat
--

ALTER TABLE ONLY merged_smreplicationstatus
    ADD CONSTRAINT merged_systemmetadatareplicationstatus_fk FOREIGN KEY (guid) REFERENCES merged_systemmetadata(guid) DEFERRABLE;

