/**
 * This work was created by participants in the DataONE project, and is
 * jointly copyrighted by participating institutions in DataONE. For 
 * more information on DataONE, see our web site at http://dataone.org.
 *
 *   Copyright ${year}
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 * 
 * $Id$
 */
package org.dataone.tidy.dao;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class ChangeRecordRepositoryTest {

    private ChangeRecordRepository repository;
    private H2RepositoryConfiguration config = new H2RepositoryConfiguration();

    @Test
    public void simpleCreateReadTest() {

        repository.save(new ChangeRecord("pid1"));
        repository.save(new ChangeRecord("foo"));
        ChangeRecord record = new ChangeRecord("bar");
        record.setAttribute("testField");
        record.setCnORC("prevVal");
        record.setAuthMN("urn:node:testNode");
        record.setChangeRule("ruleTest value");
        repository.save(record);

        Iterable<ChangeRecord> results = repository.findAll();
        System.out.println("Results found with findAll():");
        System.out.println("-------------------------------");
        int count = 0;
        for (ChangeRecord result : results) {
            System.out.println(result);
            count++;
        }
        System.out.println();
        Assert.assertEquals("Total records found did not match expected.", 3, count);

        results = repository.findByPid("bar");
        System.out.println("Change record found with findByPid('bar'):");
        System.out.println("--------------------------------------------");
        count = 0;
        for (ChangeRecord result : results) {
            System.out.println(result);
            count++;
        }
        Assert.assertEquals("Find by pid found more records than expected", 1, count);
    }

    @Before
    public void setUp() {
        config.initContext();
        repository = config.getChangeRecordRepository();
    }

    @After
    public void tearDown() {
        config.closeContext();
    }
}
